==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ZoomSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata } from "./ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata";
import { RectChangedEventArgsDescriptionMetadata } from "./RectChangedEventArgsDescriptionMetadata";
import { ZoomSliderDescription } from "./ZoomSliderDescription";
/**
 * @hidden
 */
export let ZoomSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class ZoomSliderDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Navigation.XamZoomSlider");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (ZoomSliderDescriptionMetadata.a == null) {
                ZoomSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ZoomSliderDescriptionMetadata.c(ZoomSliderDescriptionMetadata.a);
            }
            if (a.j(ZoomSliderDescriptionMetadata.a)) {
                return;
            }
            a.y(ZoomSliderDescriptionMetadata.a);
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.d(a);
            RectChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PanTransitionDuration", "Number:int");
            a.item("MaxZoomWidth", "Number:double");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
            a.item("WindowRect", "Rect");
            a.item("MinZoomWidth", "Number:double");
            a.item("StartInset", "Number:double");
            a.item("EndInset", "Number:double");
            a.item("TrackStartInset", "Number:double");
            a.item("TrackEndInset", "Number:double");
            a.item("BarExtent", "Number:double");
            a.item("Orientation", "ExportedType:string:ZoomSliderOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("LowerThumbBrush", "Brush");
            a.item("LowerThumbStrokeThickness", "Number:double");
            a.item("HigherThumbStrokeThickness", "Number:double");
            a.item("HigherThumbBrush", "Brush");
            a.item("LowerThumbOutline", "Brush");
            a.item("HigherThumbOutline", "Brush");
            a.item("LowerThumbRidgesBrush", "Brush");
            a.item("HigherThumbRidgesBrush", "Brush");
            a.item("LowerThumbWidth", "Number:double");
            a.item("HigherThumbWidth", "Number:double");
            a.item("LowerThumbHeight", "Number:double");
            a.item("HigherThumbHeight", "Number:double");
            a.item("LowerShadeBrush", "Brush");
            a.item("LowerShadeOutline", "Brush");
            a.item("LowerShadeStrokeThickness", "Number:double");
            a.item("HigherShadeBrush", "Brush");
            a.item("HigherShadeOutline", "Brush");
            a.item("HigherShadeStrokeThickness", "Number:double");
            a.item("BarBrush", "Brush");
            a.item("BarOutline", "Brush");
            a.item("BarStrokeThickness", "Number:double");
            a.item("RangeThumbBrush", "Brush");
            a.item("RangeThumbOutline", "Brush");
            a.item("RangeThumbStrokeThickness", "Number:double");
            a.item("RangeThumbRidgesBrush", "Brush");
            a.item("LowerCalloutBrush", "Brush");
            a.item("LowerCalloutTextColor", "Brush");
            a.item("LowerCalloutOutline", "Brush");
            a.item("LowerCalloutStrokeThickness", "Number:double");
            a.item("HigherCalloutBrush", "Brush");
            a.item("HigherCalloutTextColor", "Brush");
            a.item("HigherCalloutOutline", "Brush");
            a.item("HigherCalloutStrokeThickness", "Number:double");
            a.item("AreThumbCalloutsEnabled", "Boolean");
            a.item("ThumbCalloutFontFamily", "(w:ThumbCalloutFontFamily/FontFamilyTransform,xam:ThumbCalloutFontFamily,wf:ThumbCalloutFontFamily,web:thumbCalloutTextStyle/FontFamilyTransform)String");
            a.item("ThumbCalloutFontSize", "(w:ThumbCalloutFontSize,xam:ThumbCalloutFontSize,wf:ThumbCalloutFontSize,web:thumbCalloutTextStyle/FontSizeTransform)Number:double");
            a.item("ThumbCalloutFontStyle", "(w:ThumbCalloutFontStyle/FontStyleTransform,xam:ThumbCalloutFontFamily/FontStyleTransform,wf:ThumbCalloutFontFamily/FontStyleTransform,web:thumbCalloutTextStyle/FontStyleTransform)String");
            a.item("ThumbCalloutFontWeight", "(w:ThumbCalloutFontWeight/FontWeightTransform,xam:ThumbCalloutFontFamily/FontWeightTransform,wf:ThumbCalloutFontFamily/FontWeightTransform,web:thumbCalloutTextStyle/FontWeightTransform)String");
            a.item("ResolvingAxisValueRef", "EventRef::resolvingAxisValue");
            a.item("WindowRectChangedRef", "EventRef::windowRectChanged");
            ZoomSliderDescriptionMetadata.e(a);
        }
        static d(a) {
            ZoomSliderDescriptionMetadata.b(a);
            a.aa("ZoomSlider", () => new ZoomSliderDescription());
            a.z("ZoomSlider", ZoomSliderDescriptionMetadata.a);
        }
    }
    ZoomSliderDescriptionMetadata.$t = /*@__PURE__*/ markType(ZoomSliderDescriptionMetadata, 'ZoomSliderDescriptionMetadata');
    ZoomSliderDescriptionMetadata.a = null;
    return ZoomSliderDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ZoomSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata } from "./ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata";
import { RectChangedEventArgsDescriptionMetadata } from "./RectChangedEventArgsDescriptionMetadata";
import { ZoomSliderDescription } from "./ZoomSliderDescription";
/**
 * @hidden
 */
export let ZoomSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class ZoomSliderDescriptionMetadata extends Base {
        static e(a) {
            a.item("_qualifiedName", "String:Infragistics.Controls.Navigation.XamZoomSlider");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (ZoomSliderDescriptionMetadata.a == null) {
                ZoomSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ZoomSliderDescriptionMetadata.c(ZoomSliderDescriptionMetadata.a);
            }
            if (a.k(ZoomSliderDescriptionMetadata.a)) {
                return;
            }
            a.aa(ZoomSliderDescriptionMetadata.a);
            ZoomSliderResolvingAxisValueEventArgsDescriptionMetadata.d(a);
            RectChangedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PanTransitionDuration", "Number:int");
            a.item("MaxZoomWidth", "Number:double");
            a.item("PixelScalingRatio", "Number:double");
            a.item("ActualPixelScalingRatio", "Number:double");
            a.item("WindowRect", "Rect");
            a.item("MinZoomWidth", "Number:double");
            a.item("StartInset", "Number:double");
            a.item("EndInset", "Number:double");
            a.item("TrackStartInset", "Number:double");
            a.item("TrackEndInset", "Number:double");
            a.item("BarExtent", "Number:double");
            a.item("Orientation", "ExportedType:string:ZoomSliderOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("LowerThumbBrush", "Brush");
            a.item("LowerThumbStrokeThickness", "Number:double");
            a.item("HigherThumbStrokeThickness", "Number:double");
            a.item("HigherThumbBrush", "Brush");
            a.item("LowerThumbOutline", "Brush");
            a.item("HigherThumbOutline", "Brush");
            a.item("LowerThumbRidgesBrush", "Brush");
            a.item("HigherThumbRidgesBrush", "Brush");
            a.item("LowerThumbWidth", "Number:double");
            a.item("HigherThumbWidth", "Number:double");
            a.item("LowerThumbHeight", "Number:double");
            a.item("HigherThumbHeight", "Number:double");
            a.item("LowerShadeBrush", "Brush");
            a.item("LowerShadeOutline", "Brush");
            a.item("LowerShadeStrokeThickness", "Number:double");
            a.item("HigherShadeBrush", "Brush");
            a.item("HigherShadeOutline", "Brush");
            a.item("HigherShadeStrokeThickness", "Number:double");
            a.item("BarBrush", "Brush");
            a.item("BarOutline", "Brush");
            a.item("BarStrokeThickness", "Number:double");
            a.item("RangeThumbBrush", "Brush");
            a.item("RangeThumbOutline", "Brush");
            a.item("RangeThumbStrokeThickness", "Number:double");
            a.item("RangeThumbRidgesBrush", "Brush");
            a.item("LowerCalloutBrush", "Brush");
            a.item("LowerCalloutTextColor", "Brush");
            a.item("LowerCalloutOutline", "Brush");
            a.item("LowerCalloutStrokeThickness", "Number:double");
            a.item("HigherCalloutBrush", "Brush");
            a.item("HigherCalloutTextColor", "Brush");
            a.item("HigherCalloutOutline", "Brush");
            a.item("HigherCalloutStrokeThickness", "Number:double");
            a.item("AreThumbCalloutsEnabled", "Boolean");
            a.item("ThumbCalloutFontFamily", "(w:ThumbCalloutFontFamily/FontFamilyTransform,xam:ThumbCalloutFontFamily,wf:ThumbCalloutFontFamily,web:thumbCalloutTextStyle/FontFamilyTransform)String");
            a.item("ThumbCalloutFontSize", "(w:ThumbCalloutFontSize,xam:ThumbCalloutFontSize,wf:ThumbCalloutFontSize,web:thumbCalloutTextStyle/FontSizeTransform)Number:double");
            a.item("ThumbCalloutFontStyle", "(w:ThumbCalloutFontStyle/FontStyleTransform,xam:ThumbCalloutFontFamily/FontStyleTransform,wf:ThumbCalloutFontFamily/FontStyleTransform,web:thumbCalloutTextStyle/FontStyleTransform)String");
            a.item("ThumbCalloutFontWeight", "(w:ThumbCalloutFontWeight/FontWeightTransform,xam:ThumbCalloutFontFamily/FontWeightTransform,wf:ThumbCalloutFontFamily/FontWeightTransform,web:thumbCalloutTextStyle/FontWeightTransform)String");
            a.item("ResolvingAxisValueRef", "EventRef::resolvingAxisValue");
            a.item("WindowRectChangedRef", "EventRef::windowRectChanged");
            ZoomSliderDescriptionMetadata.e(a);
        }
        static d(a) {
            ZoomSliderDescriptionMetadata.b(a);
            a.ac("ZoomSlider", () => new ZoomSliderDescription());
            a.ab("ZoomSlider", ZoomSliderDescriptionMetadata.a);
        }
    }
    ZoomSliderDescriptionMetadata.$t = /*@__PURE__*/ markType(ZoomSliderDescriptionMetadata, 'ZoomSliderDescriptionMetadata');
    ZoomSliderDescriptionMetadata.a = null;
    return ZoomSliderDescriptionMetadata;
})();
